## Graph2d | Right Axis Example

This example shows the all of the graphs outlined on the right side using the `yAxisOrientation` option. We also show a few custom styles for the graph and show icons on the axis, which are adhering to the custom styling. Finally, the legend is manually positioned. Both the left and right axis have their own legend. If one of the axis is unused, the legend is not shown. The options for the legend have been split in a `left` and a `right` segment. Since this example shows the right axis, the right legend is configured.